@@ -1,13 +1,13 @@
 #!/usr/bin/perl
 #
-# $Id: fb-filelist.pl,v 4.4 1999/01/02 16:34:52 mj Exp $
+# $Id: fb-filelist.pl,v 4.6 2002/07/15 20:21:56 n0ll Exp $
 #
 # Generate file list
 #
-# Copyright (C) 1990-1999
+# Copyright (C) 1990-2002
 #  _____ _____
-# |     |___  |   Martin Junius             FIDO:      2:2452/110
-# | | | |   | |   Radiumstr. 18             Internet:  mj@fido.de
+# |     |___  |   Martin Junius             <mj@fidogate.org>
+# | | | |   | |   Radiumstr. 18
 # |_|_|_|@home|   D-51069 Koeln, Germany
 #
 $LIBDIR="<LIBDIR>";
@@ -306,7 +306,7 @@ print "########################################",
 
 print "\r\n";
 print "This list generated by:\r\n";
-print '$Id: fb-filelist.pl,v 4.4 1999/01/02 16:34:52 mj Exp $', "\r\n";
+print '$Id: fb-filelist.pl,v 4.6 2002/07/15 20:21:56 n0ll Exp $', "\r\n";
 
 if(-f $EPILOG) {
     &dump_file($EPILOG);
