@@ -1,21 +1,23 @@
 #!/bin/sh
 #
-# $Id: runpoll-binkd.sh,v 4.5 1999/11/21 17:25:34 mj Exp $
+# $Id: runpoll-binkd.sh,v 4.7 2001/01/04 20:03:43 mj Exp $
 #
-# Poll uplink
+# orodruin.fido.de's poll script using binkd
 #
 
 LIBDIR=<LIBDIR>
 BINDIR=<BINDIR>
-NEWS=<NEWSETCDIR>
 
 BINKD=/usr/sbin/binkd
 BINKDCFG=/etc/binkd/binkd.cfg
 
-XTERM=/usr/X11/bin/xterm
+XTERM=/usr/X11R6/bin/xterm
+
+DUMMYADDR="nobody@fido.de"
 
 BOSSNODE="242:1000/2"
-DUMMYADDR="nobody@fido.de"
+BOSSNAME="morannon"
+
 
 # -xterm: run in XTerm window
 if [ "$1" = "-xterm" ]; then
@@ -28,28 +30,27 @@ fi
 set -x
 
 # Send dummy mail for polling
-mail -s "POLL" $DUMMYADDR <<EOF
-POLL
-EOF
-sleep 2
+#mail -s "POLL" $DUMMYADDR <<EOF
+#POLL
+#EOF
+#sleep 2
 
 # Batch ffx news
-$NEWS/send-ffx
+$BINDIR/send-ffx
 
 # Batch ffx mail
-$LIBDIR/ftnpack -f 242:1000/1 -I %B/out.0f2/morannon
+$LIBDIR/ftnpack -f $BOSSNODE -I %B/out.0f2/$BOSSNAME
 
 # Gateway
-$NEWS/send-fidogate
+$BINDIR/send-fidogate
 
 # Tosser w/o file attachments
 $BINDIR/runtoss outpkt
 $BINDIR/runtoss outpkt/mail
 $BINDIR/runtoss outpkt/news
 
-# Poll
-#$BINDIR/out-manip poll $BOSSNODE
-$BINKD -p $BINKDCFG
+# Poll (-P requires binkd 0.9.4)
+$BINKD -P $BOSSNODE -p $BINKDCFG
 
 # Tosser, only protected inbound
 $BINDIR/rununpack pin
