@@ -2,15 +2,15 @@
 /*****************************************************************************
  * FIDOGATE --- Gateway software UNIX <-> FIDO
  *
- * $Id: address.c,v 4.14 1999/03/07 17:37:07 mj Exp $
+ * $Id: address.c,v 4.18 2003/02/16 15:38:52 n0ll Exp $
  *
  * Parsing and conversion for FIDO and RFC addresses
  *
  *****************************************************************************
- * Copyright (C) 1990-1999
+ * Copyright (C) 1990-2003
  *  _____ _____
- * |	 |___  |   Martin Junius	     FIDO:	2:2452/110
- * | | | |   | |   Radiumstr. 18  	     Internet:	mj@fido.de
+ * |	 |___  |   Martin Junius	     
+ * | | | |   | |   Radiumstr. 18  	     Internet:	mj@fidogate.org
  * |_|_|_|@home|   D-51069 Koeln, Germany
  *
  * This file is part of FIDOGATE.
@@ -49,12 +49,6 @@ static int hosts_restricted = FALSE;
 
 
 
-/*
- * Address parsing error message
- */
-char address_error[ADDRESS_ERROR_SIZE];
-
-
 #ifdef AI_6
 static char **addr_is_local_pats = NULL;
 #endif
