@@ -2,15 +2,15 @@
 /*****************************************************************************
  * FIDOGATE --- Gateway UNIX Mail/News <-> FIDO NetMail/EchoMail
  *
- * $Id: hosts.c,v 4.9 1999/04/03 12:13:21 mj Exp $
+ * $Id: hosts.c,v 4.14 2003/02/16 15:38:56 n0ll Exp $
  *
  * Process hostname <-> node aliases from hosts file
  *
  *****************************************************************************
- * Copyright (C) 1990-1999
+ * Copyright (C) 1990-2003
  *  _____ _____
- * |     |___  |   Martin Junius             FIDO:      2:2452/110
- * | | | |   | |   Radiumstr. 18             Internet:  mj@fido.de
+ * |     |___  |   Martin Junius             <mj@fidogate.org>
+ * | | | |   | |   Radiumstr. 18
  * |_|_|_|@home|   D-51069 Koeln, Germany
  *
  * This file is part of FIDOGATE.
@@ -99,11 +99,7 @@ static Host *hosts_parse_line(char *buf)
 	}
 	else			/* Add domain */
 	{
-	    char *dom = cf_hostsdomain();
-	    int l = strlen(n) + strlen(dom);
-	    p->name = xmalloc(l + 1);
-	    strcpy(p->name, n);
-	    strcat(p->name, dom);
+	    p->name = strsave2(n, cf_hostsdomain());
 	}
     }
 	
