@@ -2,15 +2,15 @@
 /*****************************************************************************
  * FIDOGATE --- Gateway UNIX Mail/News <-> FIDO NetMail/EchoMail
  *
- * $Id: message.c,v 4.16 1999/10/04 08:18:21 mj Exp $
+ * $Id: message.c,v 4.22 2003/02/16 15:38:56 n0ll Exp $
  *
  * Reading and processing FTN text body
  *
  *****************************************************************************
- * Copyright (C) 1990-1999
+ * Copyright (C) 1990-2003
  *  _____ _____
- * |     |___  |   Martin Junius             FIDO:      2:2452/110
- * | | | |   | |   Radiumstr. 18             Internet:  mj@fido.de
+ * |     |___  |   Martin Junius             <mj@fidogate.org>
+ * | | | |   | |   Radiumstr. 18
  * |_|_|_|@home|   D-51069 Koeln, Germany
  *
  * This file is part of FIDOGATE.
@@ -34,6 +34,13 @@
 
 
 
+/*
+ * Global flag for ignoring (removing) 0x8d (Soft-CR)
+ */
+int msg_ignore_0x8d = 1;
+
+
+
 /*
  * Debug output of line
  */
@@ -624,7 +631,9 @@ char *msg_xlate_line(char *buf, int n, char *line, int qp)
 	/*
 	 * Special chars require special treatment ...
 	 */
-	if(c=='\n' || c==0x8d)		/* Ignore \n and soft \r */
+	if(c == '\n')			/* Ignore \n */
+	    continue;
+	if(msg_ignore_0x8d && c==0x8d)	/* Ignore soft \r */
 	    continue;
 	if(c == '\r')
 	    c = '\n';
@@ -685,6 +694,7 @@ char *msg_xlate_line(char *buf, int n, char *line, int qp)
  * lines.
  */
 #define DEFAULT_LINE_LENGTH	72
+#define NOBREAK_LINE_LENGTH	79
 #define MAX_LINE_LENGTH		200
 
 static int msg_get_line_length(void)
@@ -723,7 +733,7 @@ int msg_format_buffer(char *buffer, Textlist *tlist)
 
     max_linelen = msg_get_line_length();
     
-    if(strlen(buffer) <= max_linelen)		/* Nothing to do */
+    if(strlen(buffer) <= NOBREAK_LINE_LENGTH)	/* Nothing to do */
     {
 	tl_append(tlist, buffer);
 	return 1;
