@@ -2,15 +2,15 @@
 /*****************************************************************************
  * FIDOGATE --- Gateway UNIX Mail/News <-> FTN NetMail/EchoMail
  *
- * $Id: mime.c,v 4.12 1999/06/01 20:59:08 mj Exp $
+ * $Id: mime.c,v 4.17 2003/02/16 15:38:56 n0ll Exp $
  *
  * MIME stuff
  *
  *****************************************************************************
- * Copyright (C) 1990-1999
+ * Copyright (C) 1990-2003
  *  _____ _____
- * |     |___  |   Martin Junius             FIDO:      2:2452/110
- * | | | |   | |   Radiumstr. 18             Internet:  mj@fido.de
+ * |     |___  |   Martin Junius             <mj@fidogate.org>
+ * | | | |   | |   Radiumstr. 18
  * |_|_|_|@home|   D-51069 Koeln, Germany
  *
  * This file is part of FIDOGATE.
@@ -64,7 +64,7 @@ static int x2toi(char *s)
  */
 char *mime_dequote(char *d, size_t n, char *s, int flags)
 {
-    int i, c;
+    int i, c=0;
     char *xl;
 
     for(i=0; i<n-1 && *s; i++, s++)
