@@ -2,15 +2,15 @@
 /*****************************************************************************
  * FIDOGATE --- Gateway UNIX Mail/News <-> FIDO NetMail/EchoMail
  *
- * $Id: misc.c,v 4.17 1999/05/22 17:30:23 mj Exp $
+ * $Id: misc.c,v 4.23 2003/02/16 15:38:57 n0ll Exp $
  *
  * Miscellaneous functions
  *
  *****************************************************************************
- * Copyright (C) 1990-1999
+ * Copyright (C) 1990-2003
  *  _____ _____
- * |	 |___  |   Martin Junius	     FIDO:	2:2452/110
- * | | | |   | |   Radiumstr. 18  	     Internet:	mj@fido.de
+ * |	 |___  |   Martin Junius	     
+ * | | | |   | |   Radiumstr. 18  	     Internet:	mj@fidogate.org
  * |_|_|_|@home|   D-51069 Koeln, Germany
  *
  * This file is part of FIDOGATE.
@@ -34,6 +34,24 @@
 
 
 
+/*
+ * str_change_ext(): change extension of string buffer containing filename
+ */
+char *str_change_ext(char *new, size_t len, char *old, char *ext)
+{
+    int off;
+
+    str_copy(new, len, old);
+    off = strlen(new) - strlen(ext);
+    if(off < 0)
+	off = 0;
+    str_copy(new+off, len-off, ext);
+
+    return new;
+}
+
+
+
 /*
  * str_printf(): wrapper for sprintf()/snprintf()
  */
@@ -46,6 +64,7 @@ int str_printf(char *buf, size_t len, const char *fmt, ...)
     
 #ifdef HAS_SNPRINTF    
     n = vsnprintf(buf, len, fmt, args);
+    /**FIXME: check for n==-1 and errno**/
 #else
     n = vsprintf(buf, fmt, args);
     if(n >= len)
@@ -55,6 +74,12 @@ int str_printf(char *buf, size_t len, const char *fmt, ...)
         return ERROR;
     }
 #endif
+    /* Make sure that buf[] is terminated with a \0. vsnprintf()
+     * should do this automatically as required by the ANSI C99
+     * proposal, but one never knows ... see also discussion on
+     * BugTraq */
+    buf[len - 1] = 0;
+
     va_end(args);
 
     return n;
