@@ -2,15 +2,15 @@
 /*****************************************************************************
  * FIDOGATE --- Gateway UNIX Mail/News <-> FIDO NetMail/EchoMail
  *
- * $Id: packet.c,v 4.14 1999/05/22 12:05:00 mj Exp $
+ * $Id: packet.c,v 4.19 2003/02/16 15:38:57 n0ll Exp $
  *
  * Functions to read/write packets and messages
  *
  *****************************************************************************
- * Copyright (C) 1990-1999
+ * Copyright (C) 1990-2003
  *  _____ _____
- * |     |___  |   Martin Junius             FIDO:      2:2452/110
- * | | | |   | |   Radiumstr. 18             Internet:  mj@fido.de
+ * |     |___  |   Martin Junius             <mj@fidogate.org>
+ * | | | |   | |   Radiumstr. 18
  * |_|_|_|@home|   D-51069 Koeln, Germany
  *
  * This file is part of FIDOGATE.
@@ -835,7 +835,7 @@ int pkt_get_hdr(FILE *fp, Packet *pkt)
     {
 	pkt->from.zone = val;
 	if(ozone != val)
-	    debug(9, "Packet: different zones %d (FTS-0001) / %d (FSC-0039)",
+	    debug(9, "Packet: different zones %d (FTS-0001) / %ld (FSC-0039)",
 		  ozone, val);
     }
     /* Dest zone (FSC-0039) */
@@ -844,7 +844,7 @@ int pkt_get_hdr(FILE *fp, Packet *pkt)
     {
 	pkt->to.zone = val;
 	if(dzone != val)
-	    debug(9, "Packet: different zones %d (FTS-0001) / %d (FSC-0039)",
+	    debug(9, "Packet: different zones %d (FTS-0001) / %ld (FSC-0039)",
 		  dzone, val);
     }
     /* Orig point (FSC-0039) */
