@@ -2,15 +2,15 @@
 /*****************************************************************************
  * FIDOGATE --- Gateway UNIX Mail/News <-> FTN NetMail/EchoMail
  *
- * $Id: parsenode.c,v 4.10 1999/04/03 13:29:02 mj Exp $
+ * $Id: parsenode.c,v 4.16 2003/02/16 15:38:57 n0ll Exp $
  *
  * Parse FTN address strings (Z:N/F.P)
  *
  *****************************************************************************
- * Copyright (C) 1990-1999
+ * Copyright (C) 1990-2003
  *  _____ _____
- * |     |___  |   Martin Junius             FIDO:      2:2452/110
- * | | | |   | |   Radiumstr. 18             Internet:  mj@fido.de
+ * |     |___  |   Martin Junius             <mj@fidogate.org>
+ * | | | |   | |   Radiumstr. 18
  * |_|_|_|@home|   D-51069 Koeln, Germany
  *
  * This file is part of FIDOGATE.
@@ -378,7 +378,6 @@ int main(int argc, char *argv[])
 	exit(0);
     }
 
-    /**NOT REACHED**/
-    return 1;
+    exit(0);
 }
 #endif /**TEST**/
