@@ -2,15 +2,15 @@
 /*****************************************************************************
  * FIDOGATE --- Gateway UNIX Mail/News <-> FIDO NetMail/EchoMail
  *
- * $Id: xalloc.c,v 4.3 1999/01/02 16:35:01 mj Exp $
+ * $Id: xalloc.c,v 4.8 2003/02/16 15:38:59 n0ll Exp $
  *
  * Safe memory allocation functions
  *
  *****************************************************************************
- * Copyright (C) 1990-1999
+ * Copyright (C) 1990-2003
  *  _____ _____
- * |	 |___  |   Martin Junius	     FIDO:	2:2452/110
- * | | | |   | |   Radiumstr. 18  	     Internet:	mj@fido.de
+ * |	 |___  |   Martin Junius	     
+ * | | | |   | |   Radiumstr. 18  	     Internet:	mj@fidogate.org
  * |_|_|_|@home|   D-51069 Koeln, Germany
  *
  * This file is part of FIDOGATE.
@@ -88,12 +88,29 @@ void xfree(void *p)
 char *strsave(char *s)
 {
     char *p;
+    size_t len;
 
     if(!s)
 	return NULL;
+
+    len = strlen(s) + 1;
+    p = xmalloc(len);
+    str_copy(p, len, s);
+
+    return p;
+}
+
+char *strsave2(char *s1, char *s2)
+{
+    char *p;
+    size_t len;
+
+    if(!s1 || !s2)
+	return NULL;
     
-    p = xmalloc(strlen(s) + 1);
-    strcpy(p, s);
+    len = strlen(s1) + strlen(s2) + 1;
+    p = xmalloc(len);
+    str_copy2(p, len, s1, s2);
 
     return p;
 }
@@ -111,5 +128,5 @@ char *strsaveline(char *s)
     r = strsave(s);
     strip_crlf(r);
 
-    return r ;
+    return r;
 }
