@@ -2,17 +2,17 @@
 /*****************************************************************************
  * FIDOGATE --- Gateway UNIX Mail/News <-> FIDO NetMail/EchoMail
  *
- * $Id: ffxqt.c,v 4.15 1999/04/03 12:13:22 mj Exp $
+ * $Id: ffxqt.c,v 4.25 2003/02/16 15:39:00 n0ll Exp $
  *
  * Process incoming ffx control and data files
  *
  * With full supporting cast of busy files and locking. ;-)
  *
  *****************************************************************************
- * Copyright (C) 1990-1999
+ * Copyright (C) 1990-2003
  *  _____ _____
- * |     |___  |   Martin Junius             FIDO:      2:2452/110
- * | | | |   | |   Radiumstr. 18             Internet:  mj@fido.de
+ * |     |___  |   Martin Junius             <mj@fidogate.org>
+ * | | | |   | |   Radiumstr. 18
  * |_|_|_|@home|   D-51069 Koeln, Germany
  *
  * This file is part of FIDOGATE.
@@ -35,10 +35,12 @@
 #include "fidogate.h"
 #include "getopt.h"
 
+#include <sys/wait.h>
+
 
 
 #define PROGRAM		"ffxqt"
-#define VERSION		"$Revision: 4.15 $"
+#define VERSION		"$Revision: 4.25 $"
 #define CONFIG		DEFAULT_CONFIG_FFX
 
 
@@ -54,6 +56,7 @@ typedef struct st_ffx
     char *job;			/* Job name */
     char *name;			/* .ffx file name */
     Node from, to;		/* FTN addresses */
+    char *fqdn;			/* Sender FQDN */
     char *passwd;		/* Password */
     char *cmd;			/* Command with args */
     char *in;			/* stdin file */
@@ -85,6 +88,7 @@ int	do_ffx			(int);
 void	remove_bad		(char *);
 FFX    *parse_ffx		(char *);
 int	exec_ffx		(FFX *);
+int	run_ffx_cmd		(char *, char *, char *, char *, char *);
 
 void	short_usage		(void);
 void	usage			(void);
@@ -134,29 +138,6 @@ void parse_ffxcmd()
 	l_cmd[n_cmd].cmd  = strsave(buffer);
 	n_cmd++;
     }
-	  
-    /* Uncompressors */
-    for(p = cf_get_string("FFXUncompress", TRUE);
-	p && *p;
-	p = cf_get_string("FFXUncompress", FALSE) )
-    {
-	if(n_cmd >= MAXFFXCMD)
-	    continue;
-	name = xstrtok(p   , "\n\t ");
-	cmd  = xstrtok(NULL, "\n");
-	if(!name || !cmd)
-	    continue;
-	while(isspace(*cmd))
-	    cmd++;
-	
-	debug(8, "config: FFXUncompress %s %s", name, cmd);
-
-	BUF_EXPAND(buffer, cmd);
-	l_cmd[n_cmd].type = 'U';
-	l_cmd[n_cmd].name = name;
-	l_cmd[n_cmd].cmd  = strsave(buffer);
-	n_cmd++;
-    }
 }
 
 
@@ -238,7 +219,8 @@ int do_ffx(int t_flag)
 	 */
 	if(!t_flag && !passwd)
 	{
-	    log("%s: no password for %s in PASSWD", name, znfp1(&ffx->from)  );
+	    log("ERROR: %s: no password for %s in PASSWD",
+		name, znfp1(&ffx->from)  );
 	    goto rename_to_bad;
 	}
 	
@@ -251,7 +233,7 @@ int do_ffx(int t_flag)
 	    {
 		if(stricmp(passwd, ffx->passwd))
 		{
-		    log("%s: wrong password from %s: ours=%s his=%s",
+		    log("ERROR: %s: wrong password from %s: ours=%s his=%s",
 			name, znfp1(&ffx->from), passwd,
 			ffx->passwd                              );
 		    goto rename_to_bad;
@@ -259,15 +241,15 @@ int do_ffx(int t_flag)
 	    }
 	    else
 	    {
-		log("%s: no password from %s: ours=%s", name,
+		log("ERROR: %s: no password from %s: ours=%s", name,
 		    znfp1(&ffx->from), passwd );
 		goto rename_to_bad;
 	    }
 	}
 
-	log("job %s: from %s data %s (%ldb) %s / %s",
+	log("job %s: from %s data %s (%ldb) / %s",
 	    ffx->job, znfp1(&ffx->from), ffx->file, check_size(ffx->file),
-	    ffx->decompr ? ffx->decompr : "", ffx->cmd                  );
+	    ffx->cmd);
 	
 	if(exec_ffx(ffx) == ERROR)
 	{
@@ -276,8 +258,7 @@ int do_ffx(int t_flag)
 	    /*
 	     * Error: rename .ffx -> .bad
 	     */
-	    strcpy(buf, name);
-	    strcpy(buf+strlen(buf)-3, "bad");
+	    str_change_ext(buf, sizeof(buf), name, "bad");
 	    rename(name, buf);
 	    log("%s: renamed to %s", name, buf);
 	}
@@ -337,9 +318,11 @@ FFX *parse_ffx(char *name)
     FILE *fp;
     static FFX ffx;
     char *buf, *p;
-    
+
+    /**FIXME: this isn't really clean**/
     xfree(ffx.job);	ffx.job     = NULL;
     xfree(ffx.name);	ffx.name    = NULL;
+    xfree(ffx.fqdn);	ffx.fqdn    = NULL;
     xfree(ffx.passwd);	ffx.passwd  = NULL;
     xfree(ffx.cmd);	ffx.cmd     = NULL;
     xfree(ffx.in);	ffx.in      = NULL;
@@ -384,6 +367,10 @@ FFX *parse_ffx(char *name)
 	    p = strtok(NULL , SEP);
 	    if(p)
 		asc_to_node(p, &ffx.to, FALSE);
+	    /* FQDN */
+	    p = strtok(NULL , SEP);
+	    if(p)
+		ffx.fqdn = strsave(p);
 	    break;
 	    
 	case 'I':
@@ -426,7 +413,7 @@ FFX *parse_ffx(char *name)
     if(!ffx.cmd)
 	return NULL;
     
-    debug(3, "ffx: %s", ffx.name);
+    debug(3, "ffx: user=%s fqdn=%s", ffx.name, ffx.fqdn ? ffx.fqdn : "-none-");
     debug(3, "     %s -> %s", znfp1(&ffx.from), znfp2(&ffx.to));
     debug(3, "     J %s", ffx.job ? ffx.job : "");
     debug(3, "     I %s %s",
@@ -447,11 +434,9 @@ FFX *parse_ffx(char *name)
 int exec_ffx(FFX *ffx)
 {
     int ret;
-    char *name, *args=NULL, *cmd_c=NULL, *cmd_u=NULL;
+    char *name, *args=NULL, *cmd_c=NULL;
     
-    /*
-     * Extract command name and args
-     */
+    /* Extract command name and args */
     name = strtok(ffx->cmd, "\n\t ");
     args = strtok(NULL,     "\n"   );
     if(!name)
@@ -461,9 +446,7 @@ int exec_ffx(FFX *ffx)
     while(isspace(*args))
 	args++;
 
-    /*
-     * Find command and uncompressor
-     */
+    /* Find command and uncompressor */
     cmd_c = find_ffxcmd('C', name);
     if(!cmd_c)
     {
@@ -472,47 +455,13 @@ int exec_ffx(FFX *ffx)
     }
     if(ffx->decompr) 
     {
-	cmd_u = find_ffxcmd('U', ffx->decompr);
-	if(!cmd_u)
-	{
-	    log("ERROR: no FFXUncompress found for \"%s\"", ffx->decompr);
-	    return ERROR;
-	}
-    }
-    
-
-    /*
-     * Execute
-     */
-    if(ffx->in)
-    {
-	/* Search for data file, ignoring case */
-	if(dir_search(".", ffx->in) == NULL)
-	{
-	    log("ERROR: can't find data file %s", ffx->in);
-	    return ERROR;
-	}
-	/* Feed data file as stdin to command, optionally decompressing */
-	if(ffx->decompr)		/* Data file with compression */
-	    str_printf(buffer, sizeof(buffer),
-		       "%s %s | %s %s", cmd_u, ffx->in, cmd_c, args);
-	else				/* No compression */
-	    str_printf(buffer, sizeof(buffer),
-		       "%s %s <%s", cmd_c, args, ffx->in);
-    }
-    else
-    {
-	/* Execute command without data file */
-	str_printf(buffer, sizeof(buffer), "%s %s", cmd_c, args);
+	log("ERROR: uncompressing no longer supported in this version");
+	return ERROR;
     }
 
-    /*
-     * FIXME: should do some proper calls to fork(), exec(), pipe() etc.
-     * system() calls /bin/sh which is inefficient and creates security
-     * problems.
-     */
-    debug(2, "Command: %s", buffer);
-    ret = run_system(buffer);
+    /* Execute */
+    debug(2, "Command: %s", cmd_c);
+    ret = run_ffx_cmd(cmd_c, name, ffx->fqdn, args, ffx->in);
     debug(2, "Exit code=%d", ret);
 
     if(ret == 0)
@@ -528,6 +477,93 @@ int exec_ffx(FFX *ffx)
 
 
 
+/*
+ * Run ffx cmd using fork() and exec()
+ */
+#define MAXARGS		256
+
+int run_ffx_cmd(char *cmd,
+		char *cmd_name, char *cmd_fqdn, char *cmd_args, char *data)
+{
+    char *args[MAXARGS];
+    int n=0;
+    char *p;
+    pid_t pid;
+    int status;
+
+    /* compile args[] vector */
+    args[n++] = cmd_name;
+    if(cmd_fqdn && streq(cmd_name, "rmail")) 
+    {
+	args[n++] = "-f";
+	args[n++] = cmd_fqdn;
+    }
+
+    for(p=strtok(cmd_args, SEP); p; p=strtok(NULL, SEP)) 
+    {
+	if(n >= MAXARGS-1) 
+	{
+	    log("ERROR: too many args in run_ffx_cmd()");
+	    return ERROR;
+	}
+	args[n++] = p;
+    }
+
+    args[n] = NULL;
+
+#if 0
+    {
+	int i;
+	debug(7, "cmd=%s", cmd);
+	for(i=0; i<=n; i++)
+	    debug(7, "args[%d] = %s", i, args[i]);
+	debug(7, "data=%s", data);
+    }
+#endif
+
+    /* fork() and exec() */
+    pid = fork();
+    if(pid == ERROR) 
+    {
+	log("$ERROR: fork failed");
+	return ERROR;
+    }
+
+    if(pid) 
+    {
+	/* parent */
+	if(waitpid(pid, &status, 0) == ERROR) 
+	{
+	    log("$ERROR: waitpid failed");
+	    return ERROR;
+	}
+	if(WIFEXITED(status))
+	    return WEXITSTATUS(status);
+	if(WIFSIGNALED(status)) 
+	    log("ERROR: child %s caught signal %d", cmd, WTERMSIG(status));
+	else
+	    log("ERROR: child %s, exit status=%04x", cmd, status);
+	return ERROR;
+    }
+    else 
+    {
+	/* child */
+	if(! freopen(data, R_MODE, stdin)) 
+	{
+	    log("ERROR: can't freopen stdin to %s", data);
+	    exit(1);
+	}
+	if( execv(cmd, args) == ERROR )
+	    log("ERROR: execv %s failed", cmd);
+	exit(1);
+    }
+
+    /**NOT REACHED**/
+    return ERROR;
+}
+
+
+
 /*
  * Usage messages
  */
@@ -658,7 +694,4 @@ int main(int argc, char **argv)
 
 
     exit(0);
-
-    /**NOT REACHED**/
-    return 1;
 }
