@@ -2,15 +2,15 @@
 /*****************************************************************************
  * FIDOGATE --- Gateway UNIX Mail/News <-> FIDO NetMail/EchoMail
  *
- * $Id: ftn2rfc.c,v 4.53 1999/10/04 08:18:23 mj Exp $
+ * $Id: ftn2rfc.c,v 4.62 2003/02/16 15:39:00 n0ll Exp $
  *
  * Convert FTN mail packets to RFC mail and news batches
  *
  *****************************************************************************
- * Copyright (C) 1990-1999
+ * Copyright (C) 1990-2003
  *  _____ _____
- * |     |___  |   Martin Junius             FIDO:      2:2452/110
- * | | | |   | |   Radiumstr. 18             Internet:  mj@fido.de
+ * |     |___  |   Martin Junius             <mj@fidogate.org>
+ * | | | |   | |   Radiumstr. 18
  * |_|_|_|@home|   D-51069 Koeln, Germany
  *
  * This file is part of FIDOGATE.
@@ -40,7 +40,7 @@
 
 
 #define PROGRAM 	"ftn2rfc"
-#define VERSION 	"$Revision: 4.53 $"
+#define VERSION 	"$Revision: 4.62 $"
 #define CONFIG		DEFAULT_CONFIG_GATE
 
 
@@ -370,7 +370,7 @@ int unpack(FILE *pkt_file, Packet *pkt)
 
 	/* Replace empty subject */
 	if (!*msg.subject)
-	    strcpy(msg.subject, "(no subject)");
+	    BUF_COPY(msg.subject, "(no subject)");
 	
 	/*
 	 * Read message body
@@ -386,6 +386,10 @@ int unpack(FILE *pkt_file, Packet *pkt)
 	    {
 		log("ERROR: reading input packet");
 		ret = ERROR;
+		tl_clear(&theader);
+		tl_clear(&tbody);
+		tl_clear(&tl);
+		msg_body_clear(&body);
 		break;
 	    }
 	}
@@ -468,6 +472,10 @@ int unpack(FILE *pkt_file, Packet *pkt)
 	    if(!area->group && !ftn_junk_group)
 	    {
 		log("unknown area %s", area->area);
+		tl_clear(&theader);
+		tl_clear(&tbody);
+		tl_clear(&tl);
+		msg_body_clear(&body);
 		continue;
 	    }
 	}
@@ -584,9 +592,11 @@ int unpack(FILE *pkt_file, Packet *pkt)
 	    if(*p == '\001')			/* Kludge in message body */
 	    {
 		if(strnieq(p + 1, "CHRS: ", 6))
-		    cs_in = charset_chrs_name(p + 6);
+		    if( (s = charset_chrs_name(p + 6)) )
+			cs_in = s;
 		if(strnieq(p + 1, "CHARSET: ", 9))
-		    cs_in = charset_chrs_name(p + 9);
+		    if( (s = charset_chrs_name(p + 9)) )
+			cs_in = s;
 		/**FIXME: change in/out charset if needed**/
 	    }
 	    else				/* Normal line */
@@ -606,6 +616,8 @@ int unpack(FILE *pkt_file, Packet *pkt)
 	/*
 	 * Convert FTN from/to addresses to RFCAddr struct
 	 */
+	if(!cs_in)
+	    cs_in = cs_def;
 	charset_set_in_out(cs_in, CHARSET_STD7BIT);
 	addr_from = rfcaddr_from_ftn(msg.name_from, &msg.node_orig);
 	addr_to   = rfcaddr_from_ftn(msg.name_to,   &msg.node_to  );
@@ -636,6 +648,10 @@ int unpack(FILE *pkt_file, Packet *pkt)
 	    if( (p = kludge_get(&body.kludge, "SPLIT", NULL)) )
 	    {
 		log("skipping split message, origin=%s", znfp1(&msg.node_orig));
+		tl_clear(&theader);
+		tl_clear(&tbody);
+		tl_clear(&tl);
+		msg_body_clear(&body);
 		continue;
 	    }
 	}
@@ -650,6 +666,10 @@ int unpack(FILE *pkt_file, Packet *pkt)
 	    {
 		log("skipping message from gateway, area %s, origin=%s",
 		    area->area, znfp1(&msg.node_orig));
+		tl_clear(&theader);
+		tl_clear(&tbody);
+		tl_clear(&tl);
+		msg_body_clear(&body);
 		continue;
 	    }
 	
@@ -659,6 +679,10 @@ int unpack(FILE *pkt_file, Packet *pkt)
 	    {
 		log("skipping message from gateway (GIGO), area %s, origin=%s",
 		    area->area, znfp1(&msg.node_orig));
+		tl_clear(&theader);
+		tl_clear(&tbody);
+		tl_clear(&tl);
+		msg_body_clear(&body);
 		continue;
 	    }
 
@@ -667,6 +691,10 @@ int unpack(FILE *pkt_file, Packet *pkt)
 	    {
 		log("skipping message from gateway (X-FZ-SPLIT), area %s, origin=%s",
 		    area->area, znfp1(&msg.node_orig));
+		tl_clear(&theader);
+		tl_clear(&tbody);
+		tl_clear(&tl);
+		msg_body_clear(&body);
 		continue;
 	    }
 	}
@@ -739,6 +767,9 @@ int unpack(FILE *pkt_file, Packet *pkt)
 	    log("BOUNCE: insecure mail from %s",
 		s_rfcaddr_to_asc(&addr_from, TRUE));
 	    bounce_mail("insecure", &addr_from, &msg, msgbody_rfc_to, &tbody);
+	    tl_clear(&theader);
+	    tl_clear(&tbody);
+	    tl_clear(&tl);
 	    continue;
 	}
 	    
@@ -783,6 +814,10 @@ int unpack(FILE *pkt_file, Packet *pkt)
 		    s_rfcaddr_to_asc(&addr_from, TRUE));
 		bounce_mail("restricted", &addr_from, &msg,
 			    msgbody_rfc_to, &tbody);
+		tl_clear(&theader);
+		tl_clear(&tbody);
+		tl_clear(&tl);
+		msg_body_clear(&body);
 		continue;
 	    }
 
@@ -795,6 +830,10 @@ int unpack(FILE *pkt_file, Packet *pkt)
 		    s_rfcaddr_to_asc(&addr_from, TRUE));
 		bounce_mail("down", &addr_from, &msg,
 			    msgbody_rfc_to, &tbody);
+		tl_clear(&theader);
+		tl_clear(&tbody);
+		tl_clear(&tl);
+		msg_body_clear(&body);
 		continue;
 	    }
 	}	    
@@ -814,6 +853,10 @@ int unpack(FILE *pkt_file, Packet *pkt)
 			s_rfcaddr_to_asc(&addr_from, TRUE), mail_to           );
 		    bounce_mail("addrinto",
 				&addr_from, &msg, msgbody_rfc_to, &tbody);
+		    tl_clear(&theader);
+		    tl_clear(&tbody);
+		    tl_clear(&tl);
+		    msg_body_clear(&body);
 		    continue;
 		}
 		else
@@ -839,6 +882,10 @@ int unpack(FILE *pkt_file, Packet *pkt)
 		log("BOUNCE: mail from %s without To line",
 		    s_rfcaddr_to_asc(&addr_from, TRUE));
 		bounce_mail("noto", &addr_from, &msg, msgbody_rfc_to, &tbody);
+		tl_clear(&theader);
+		tl_clear(&tbody);
+		tl_clear(&tl);
+		msg_body_clear(&body);
 		continue;
 	    }
 
@@ -857,7 +904,7 @@ int unpack(FILE *pkt_file, Packet *pkt)
 	    
 	    rfc = rfcaddr_from_rfc(msgbody_rfc_from);
 	    if(!rfc.real[0])
-		strcpy(rfc.real, addr_from.real);
+		BUF_COPY(rfc.real, addr_from.real);
 	    
 	    addr_from = rfc;
 	}
@@ -912,6 +959,10 @@ int unpack(FILE *pkt_file, Packet *pkt)
 		if(!strncmp(p, "<NOMSGID_", 9))
 		{
 		    log("MSGID: %s, not gated", p);
+		    tl_clear(&theader);
+		    tl_clear(&tbody);
+		    tl_clear(&tl);
+		    msg_body_clear(&body);
 		    continue;
 		}
 		id_line = s_msgid_fido_to_rfc(p, &id_zone);
@@ -919,6 +970,10 @@ int unpack(FILE *pkt_file, Packet *pkt)
 		    if(id_zone>=-1 && !cf_zones_check(id_zone))
 		    {
 			log("MSGID %s: malformed or unknown zone, not gated", p);
+			tl_clear(&theader);
+			tl_clear(&tbody);
+			tl_clear(&tl);
+			msg_body_clear(&body);
 			continue;
 		    }
 	    }
@@ -927,6 +982,10 @@ int unpack(FILE *pkt_file, Packet *pkt)
 		if(no_messages_without_msgid)
 		{
 		    log("MSGID: none, not gated");
+		    tl_clear(&theader);
+		    tl_clear(&tbody);
+		    tl_clear(&tl);
+		    msg_body_clear(&body);
 		    continue;
 		}
 		id_line = s_msgid_default(&msg);
@@ -936,6 +995,10 @@ int unpack(FILE *pkt_file, Packet *pkt)
 	if(!id_line)
 	{
 	    log("ERROR: id_line==NULL, strange.");
+	    tl_clear(&theader);
+	    tl_clear(&tbody);
+	    tl_clear(&tl);
+	    msg_body_clear(&body);
 	    continue;
 	}
 	
@@ -1169,6 +1232,10 @@ int unpack(FILE *pkt_file, Packet *pkt)
 	    mail_close('m');
 	}
 
+	tl_clear(&theader);
+	tl_clear(&tbody);
+	tl_clear(&tl);
+	msg_body_clear(&body);
 	tmps_freeall();
     } /**while(type == MSG_TYPE)**/
 
@@ -1180,32 +1247,6 @@ int unpack(FILE *pkt_file, Packet *pkt)
 
 
 
-/*
- * Rename .pkt -> .bad
- */
-int rename_bad(char *name)
-{
-    char bad[MAXPATH];
-    int len;
-    
-    BUF_COPY(bad, name);
-    len = strlen(bad) - 4;
-    if(len < 0)
-	len = 0;
-    strcpy(bad + len, ".bad");
-    
-    log("ERROR: bad packet renamed to %s", bad);
-    if(rename(name, bad) == ERROR)
-    {
-	log("$ERROR: can't rename %s -> %s", name, bad);
-	return ERROR;
-    }
-    
-    return OK;
-}
-
-
-
 /*
  * Unpack one packet file
  */
@@ -1562,6 +1603,12 @@ int main(int argc, char **argv)
 	debug(8, "config: NetMailCharsetUse1st");
 	netmail_charset_use_1st = TRUE;
     }
+    if(cf_get_string("DontIgnore0x8d", TRUE)   ||
+       cf_get_string("DontIgnoreSoftCR", TRUE)   )
+    {
+	debug(8, "config: DontIgnore0x8d");
+	msg_ignore_0x8d = FALSE;
+    }
     
     /* Init various modules */
     areas_init();
@@ -1626,7 +1673,4 @@ int main(int argc, char **argv)
 	unlock_program(PROGRAM);
     
     exit(ret);
-
-    /**NOT REACHED**/
-    return 1;
 }
