@@ -2,7 +2,7 @@
 /*****************************************************************************
  * FIDOGATE --- Gateway UNIX Mail/News <-> FIDO NetMail/EchoMail
  *
- * $Id: ftnin.c,v 4.12 1999/04/03 12:13:23 mj Exp $
+ * $Id: ftnin.c,v 4.17 2003/02/16 15:39:01 n0ll Exp $
  *
  * Search for mail packets destined to gateway's FTN addresses and feed
  * them to ftn2rfc.
@@ -10,10 +10,10 @@
  * With full supporting cast of busy files and locking. ;-)
  *
  *****************************************************************************
- * Copyright (C) 1990-1999
+ * Copyright (C) 1990-2003
  *  _____ _____
- * |     |___  |   Martin Junius             FIDO:      2:2452/110
- * | | | |   | |   Radiumstr. 18             Internet:  mj@fido.de
+ * |     |___  |   Martin Junius             <mj@fidogate.org>
+ * | | | |   | |   Radiumstr. 18
  * |_|_|_|@home|   D-51069 Koeln, Germany
  *
  * This file is part of FIDOGATE.
@@ -39,7 +39,7 @@
 
 
 #define PROGRAM		"ftnin"
-#define VERSION		"$Revision: 4.12 $"
+#define VERSION		"$Revision: 4.17 $"
 #define CONFIG		DEFAULT_CONFIG_GATE
 
 
@@ -355,7 +355,4 @@ int main(int argc, char **argv)
     do_packets();
 
     exit(0);
-
-    /**NOT REACHED**/
-    return 1;
 }
