@@ -2,15 +2,15 @@
 /*****************************************************************************
  * FIDOGATE --- Gateway software UNIX <-> FIDO
  *
- * $Id: rfc2ftn.c,v 4.56 1999/08/08 09:14:32 mj Exp $
+ * $Id: rfc2ftn.c,v 4.70 2003/02/16 15:39:01 n0ll Exp $
  *
  * Read mail or news from standard input and convert it to a FIDO packet.
  *
  *****************************************************************************
- * Copyright (C) 1990-1999
+ * Copyright (C) 1990-2003
  *  _____ _____
- * |     |___  |   Martin Junius             FIDO:      2:2452/110
- * | | | |   | |   Radiumstr. 18             Internet:  mj@fido.de
+ * |     |___  |   Martin Junius             <mj@fidogate.org>
+ * | | | |   | |   Radiumstr. 18
  * |_|_|_|@home|   D-51069 Koeln, Germany
  *
  * This file is part of FIDOGATE.
@@ -39,7 +39,7 @@
 
 
 #define PROGRAM 	"rfc2ftn"
-#define VERSION 	"$Revision: 4.56 $"
+#define VERSION 	"$Revision: 4.70 $"
 #define CONFIG		DEFAULT_CONFIG_GATE
 
 
@@ -116,6 +116,13 @@ static int dont_use_reply_to = FALSE;	/* DontUseReplyTo      	 */
 static int replyaddr_ifmail_tx = FALSE;	/* ReplyAddrIfmailTX   	 */
 static int check_areas_bbs = FALSE;	/* CheckAreasBBS       	 */
 static int use_x_for_tearline = FALSE;	/* UseXHeaderForTearline */
+static int dont_change_content_type_charset = FALSE;
+					/* DontChangeContentTypeCharset */
+static int dont_process_return_receipt_to = FALSE;
+					/* DontProcessReturnReceiptTo */
+static int registered_hosts_only = FALSE;	/* RegisteredHostsOnly */
+static int registered_aliases_only = FALSE;	/* RegisteredAliasesOnly */
+
 
 /* Charset stuff */
 static char *default_charset_out = NULL;
@@ -137,13 +144,14 @@ int private = TRUE;
 /* News-article */
 int newsmode = FALSE;
 
-
-
-/*
- * Global Textlist to save message body
- */
+/* Global Textlist to save message body */
 Textlist body = { NULL, NULL };
 
+/* Address parsing error message */
+#define ADDRESS_ERROR_SIZE 256
+static char address_error[ADDRESS_ERROR_SIZE];
+static int  address_exit = 0;
+
 
 
 /*
@@ -539,6 +547,7 @@ int rfc_parse(RFCAddr *rfc, char *name, Node *node, int gw)
 		    str_printf(address_error, sizeof(address_error),
 			       "FTN address %s: currently down, unreachable",
 			       znfp1(n));
+		    address_exit = EX_NOHOST;
 		    ret = ERROR;
 		}
 	    }
@@ -551,6 +560,7 @@ int rfc_parse(RFCAddr *rfc, char *name, Node *node, int gw)
 	    str_printf(address_error, sizeof(address_error),
 		       "FTN address %s: not registered for this domain",
 		       znfp1(n));
+	    address_exit = EX_NOHOST;
 	    ret = ERROR;
 	}
 
@@ -562,6 +572,7 @@ int rfc_parse(RFCAddr *rfc, char *name, Node *node, int gw)
 	    str_printf(address_error, sizeof(address_error),
 		       "FTN address %s: zone %d not supported",
 		       znfp1(n), n->zone);
+	    address_exit = EX_NOHOST;
 	    ret = ERROR;
 	}
 	
@@ -574,7 +585,7 @@ int rfc_parse(RFCAddr *rfc, char *name, Node *node, int gw)
 	 */
 	*node = cf_gateway();
 	if(name)
-	    strcpy(name, "UUCP");
+	    str_copy(name, MSG_MAXNAME, "UUCP");
 	
 	ret = OK;
     }
@@ -648,18 +659,16 @@ char *receiver(char *to, Node *node)
     static char name[MSG_MAXNAME];
     Alias *alias;
     
-    /*
-     * Check for name alias
-     */
+    /* Check for name alias */
     debug(5, "Name for alias checking: %s", to);
 
-    /**FIXME: why && !alias->userdom?**/
+    /* search alias, use only plain (no @do.main) aliases */
     if( (alias = alias_lookup(node, to, NULL)) && !alias->userdom )
     {
 	debug(5, "Alias found: %s %s %s", alias->username,
 	      znfp1(&alias->node), alias->fullname);
-	strcpy(name, alias->fullname);
-	/* Store address from ALIASES into node, this will reroute the
+	BUF_COPY(name, alias->fullname);
+	/* Store address from ALIASES into node, this will reroute the asdf 
 	 * message to the point specified in ALIASES, if the message
 	 * addressed to node without point address.  */
 	*node = alias->node;
@@ -667,19 +676,38 @@ char *receiver(char *to, Node *node)
 	return name;
     }
     
-    /*
-     * Alias not found. Return the the original receiver processed by
-     * convert_user_name().
-     */
+    /* No alias, return the the original receiver processed by
+     * convert_user_name() */
     BUF_COPY(name, to);
     cvt_user_name(name);
+    debug(6, "Converted receiver name: %s", name);
+
+    /* Search full name in aliases */
+    if( (alias = alias_lookup(node, NULL, name)) )
+    {
+	debug(5, "Alias (full name) found: %s %s %s", alias->username,
+	      znfp1(&alias->node), alias->fullname);
+	*node = alias->node;
+	return name;
+    }
 
     /**FIXME: implement a generic alias with pattern matching**/
-    /*
-     * Convert "postmaster" to "sysop"
-     */
+    /* Convert "postmaster" to "sysop" */
     if(!stricmp(name, "postmaster"))
+    {
 	BUF_COPY(name, "Sysop");
+	debug(5, "Alias postmaster: return %s", name);
+	return name;
+    }
+
+    /* If RegisteredAliasesOnly is set, flag missing alias as error */
+    if(!newsmode && registered_aliases_only) 
+    {
+	debug(5, "No alias found: returning address error");
+	BUF_COPY(address_error, "recipient is unknown");
+	address_exit = EX_NOUSER;
+	return NULL;
+    }
     
     debug(5, "No alias found: return %s", name);
 
@@ -703,7 +731,7 @@ char *mail_receiver(RFCAddr *rfc, Node *node)
 	 * Address is argument
 	 */
 	if(rfc_parse(rfc, name, node, TRUE) == ERROR) {
-	    log("BOUNCE: <%s>, %s", s_rfcaddr_to_asc(rfc, TRUE),
+	    log("BOUNCE: to=%s, reject=%s", s_rfcaddr_to_asc(rfc, TRUE),
 		(*address_error ? address_error : "unknown")  );
 	    return NULL;
 	}
@@ -791,7 +819,7 @@ char *mail_sender(RFCAddr *rfc, Node *node)
     {
 	debug(5, "Alias found: %s %s %s", alias->username,
 	      znfp1(&alias->node), alias->fullname);
-	strcpy(name, alias->fullname);
+	BUF_COPY(name, alias->fullname);
 	*node = alias->node;
 	return name;
     }
@@ -803,7 +831,7 @@ char *mail_sender(RFCAddr *rfc, Node *node)
 	alias_extended = TRUE;
 	debug(5, "Alias found: %s@%s %s %s", alias->username, alias->userdom,
 	      znfp1(&alias->node), alias->fullname);
-	strcpy(name, alias->fullname);
+	BUF_COPY(name, alias->fullname);
 	*node = alias->node;
 	return name;
     }
@@ -880,13 +908,13 @@ int snd_mail(RFCAddr rfc_to, long size)
      */
     p = mail_receiver(&rfc_to, &node_to);
     if(!p) {
-	if(*address_error)
-	    sendback("Address %s:\n  %s",
-		     s_rfcaddr_to_asc(&rfc_to, TRUE), address_error);
-	else
-	    sendback("Address %s:\n  address/host is unknown",
-		     s_rfcaddr_to_asc(&rfc_to, TRUE)               );
-	TMPS_RETURN(EX_NOHOST);
+	char *msg = *address_error ? address_error : "address/host is unknown";
+	
+	sendback("Address %s:\n  %s", s_rfcaddr_to_asc(&rfc_to, TRUE), msg);
+	log("BOUNCE: from=%s, to=%s, reject=%s",
+	    s_rfcaddr_to_asc(&rfc_from, TRUE),
+	    s_rfcaddr_to_asc(&rfc_to, TRUE), msg);
+	TMPS_RETURN(address_exit ? address_exit : EX_NOHOST);
     }
     BUF_COPY(msg.name_to, p);
     fido = rfc_isfido();
@@ -935,9 +963,10 @@ int snd_mail(RFCAddr rfc_to, long size)
 	if(limitsize>0 && size>limitsize)
 	{
 	    /* Too large, don't gate it */
-	    log("message too big (%ldb, limit %ldb) for mail %s -> %s",
-		size, limitsize, s_rfcaddr_to_asc(&rfc_from, TRUE),
-		s_rfcaddr_to_asc(&rfc_to, TRUE)                            );
+	    log("BOUNCE: from=%s, to=%s, "
+		"reject=message too big (%ldb, limit %ldb)",
+		s_rfcaddr_to_asc(&rfc_from, TRUE),
+		s_rfcaddr_to_asc(&rfc_to, TRUE), size, limitsize );
 	    sendback("Address %s:\n  message too big (%ldb, limit %ldb)",
 		     s_rfcaddr_to_asc(&rfc_to, TRUE), size, limitsize      );
 	    TMPS_RETURN(EX_UNAVAILABLE);
@@ -1007,7 +1036,8 @@ int snd_mail(RFCAddr rfc_to, long size)
 	/*
 	 * Return-Receipt-To -> RRREQ flag
 	 */
-	if( (p = header_get("Return-Receipt-To")) )
+	if(!dont_process_return_receipt_to &&
+	   (p = header_get("Return-Receipt-To")) )
 	   msg.attr |= MSG_RRREQ;
     }
     
@@ -1046,7 +1076,6 @@ int snd_mail(RFCAddr rfc_to, long size)
 	xpost_flag = strchr(groups, ',') != NULL;
 
 	/* List of newsgroups -> textlist (strtok is not reentrant!) */
-	tl_clear(&tl);
 	for(p=strtok(groups, ","); p; p=strtok(NULL, ","))
 	    tl_append(&tl, p);
 
@@ -1126,18 +1155,24 @@ int snd_mail(RFCAddr rfc_to, long size)
 		msg.node_from = cf_n_addr();
 		msg.node_to   = cf_n_uplink();
 		status = snd_message(&msg, pa, rfc_from, rfc_to,
-				     subj, size, flags, fido, mime, &node_from);
-		if(status)
+				     subj, size, flags, fido, mime,
+				     &node_from);
+		if(status) {
+		    tl_clear(&tl);
 		    TMPS_RETURN(status);
+		}
 	    }
 	}
+
+	tl_clear(&tl);
     }
     else {
 	/*
 	 * NetMail message
 	 */
-	log("MAIL: %s -> %s",
-	    s_rfcaddr_to_asc(&rfc_from, TRUE), s_rfcaddr_to_asc(&rfc_to, TRUE));
+	log("MAIL: from=%s, to=%s",
+	    s_rfcaddr_to_asc(&rfc_from, TRUE),
+	    s_rfcaddr_to_asc(&rfc_to, TRUE));
 	msg.area      = NULL;
 	msg.node_from = node_from;
 	msg.node_to   = node_to;
@@ -1230,6 +1265,14 @@ int snd_message(Message *msg, Area *parea,
     str_upper(cs_out_fsc);
     cs_enc = strieq(cs_out_rfc, "us-ascii") ? "7bit" : "8bit";
     charset_set_in_out(cs_in, cs_out);
+    if(dont_change_content_type_charset) 
+    {
+	if(!strieq(cs_in, cs_out_rfc))
+	{
+	    debug(6, "charset: cs_out_rfc set to original %s", cs_in);
+	    cs_out_rfc = cs_in;
+	}
+    }
     debug(6, "charset: msg RFC=%s FSC=%s enc=%s",
 	  cs_out_rfc, cs_out_fsc, cs_enc         );
 
@@ -1835,7 +1878,7 @@ int main(int argc, char **argv)
     char *c_flag=NULL;
     char *a_flag=NULL, *u_flag=NULL;
     char *areas_bbs=NULL;
-    FILE *fp, *fpart, *fppos;
+    FILE *fp=NULL, *fpart, *fppos;
     char article[MAXPATH];
     long pos;
     char posfile[MAXPATH];
@@ -2107,6 +2150,23 @@ int main(int argc, char **argv)
 	strtok(p, ":");
 	netmail_charset_out = strtok(NULL, ":");
     }
+    if( (p = cf_get_string("DontChangeContentTypeCharset", TRUE)) )
+    {
+	dont_change_content_type_charset = TRUE;
+    }
+    if( (p = cf_get_string("DontProcessReturnReceiptTo", TRUE)) )
+    {
+	dont_process_return_receipt_to = TRUE;
+    }
+    if( (p = cf_get_string("RegisteredHostsOnly", TRUE)) )
+    {
+	registered_hosts_only = TRUE;
+    }
+    if( (p = cf_get_string("RegisteredAliasesOnly", TRUE)) )
+    {
+	registered_aliases_only = TRUE;
+    }
+
 
     /*
      * Process local options
@@ -2280,7 +2340,4 @@ int main(int argc, char **argv)
     }
     
     exit(status);
-
-    /**NOT REACHED**/
-    return 1;
 }
