@@ -2,15 +2,15 @@
 /*****************************************************************************
  * FIDOGATE --- Gateway UNIX Mail/News <-> FTN NetMail/EchoMail
  *
- * $Id: prototypes.h,v 4.61 1999/07/23 21:30:12 mj Exp $
+ * $Id: prototypes.h,v 4.69 2003/02/16 15:39:01 n0ll Exp $
  *
  * Prototypes for functions in libfidogate.a
  *
  *****************************************************************************
- * Copyright (C) 1990-1999
+ * Copyright (C) 1990-2003
  *  _____ _____
- * |     |___  |   Martin Junius             FIDO:      2:2452/110
- * | | | |   | |   Radiumstr. 18             Internet:  mj@fido.de
+ * |     |___  |   Martin Junius             <mj@fidogate.org>
+ * | | | |   | |   Radiumstr. 18
  * |_|_|_|@home|   D-51069 Koeln, Germany
  *
  * This file is part of FIDOGATE.
@@ -30,6 +30,13 @@
  * Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
  *****************************************************************************/
 
+/* define __attribute__ to nothing for non GNU */
+#ifndef __GNUC__
+# define __attribute__(x)	/*nothing*/
+#endif
+
+
+
 #ifdef AI_8
 /* acl.c */
 void	acl_init		(void);
@@ -44,8 +51,6 @@ int	list_match		(register int, char **, char **);
 
 /* address.c */
 extern int i_flag;
-#define ADDRESS_ERROR_SIZE	256
-extern char address_error[ADDRESS_ERROR_SIZE];
 
 void	addr_restricted		(int);
 int	addr_is_restricted	(void);
@@ -186,7 +191,7 @@ unsigned long crc32_file	(char *);
 
 /* date.c */
 char   *date			(char *, time_t *);
-char   *date_buf		(char *, char *, time_t *);
+char   *date_buf		(char *, size_t, char *, time_t *);
 
 /* dir.c */
 #define DIR_SORTNAME	'n'
@@ -201,11 +206,8 @@ void	dir_sortmode		(int);
 char   *dir_get			(int);
 char   *dir_search		(char *, char *);
 
-/* exit.c */
-typedef int (*ExitHandlerF) (int);
-
-void	exit_handler		(ExitHandlerF);
-void	fidogate_exit		(int);
+/* file.c */
+int	rename_bad		(char *);
 
 /* flo.c */
 FILE   *flo_file		(void);
@@ -268,11 +270,14 @@ extern int verbose;
 extern int no_debug;
 
 char   *strerror		(int);
-void	log			(const char *, ...);
-void	debug			(int, const char *, ...);
+void	log			(const char *, ...)
+    __attribute__ ((format (printf, 1, 2)));
+void	debug			(int, const char *, ...)
+    __attribute__ ((format (printf, 2, 3)));
 void	log_file		(char *);
 void	log_program		(char *);
-void	logx			(char *, char *, char *, ...);
+void	logx			(char *, char *, char *, ...)
+    __attribute__ ((format (printf, 3, 4)));
 
 /* mail.c */
 extern char mail_dir[MAXPATH];
@@ -289,6 +294,8 @@ Maus   *maus_default		(void);
 Maus   *maus_lookup		(char *);
 
 /* message.c */
+extern int msg_ignore_0x8d;
+
 int	pkt_get_line		(FILE *, char *, int);
 int	pkt_get_body		(FILE *, Textlist *);
 void	msg_body_init		(MsgBody *);
@@ -310,7 +317,9 @@ char   *mime_dequote		(char *, size_t, char *, int);
 char   *mime_deheader		(char *, size_t, char *, int);
 
 /* misc.c */
-int	str_printf		(char *, size_t, const char *, ...);
+char   *str_change_ext		(char *, size_t, char *, char *);
+int	str_printf		(char *, size_t, const char *, ...)
+    __attribute__ ((format (printf, 3, 4)));
 int	str_last		(char *, size_t);
 char   *str_lastp		(char *, size_t);
 char   *str_lower		(char *);
@@ -531,7 +540,8 @@ void	tl_remove		(Textlist *, Textline *);
 void	tl_delete		(Textlist *, Textline *);
 void	tl_init			(Textlist *);
 void	tl_append		(Textlist *, char *);
-void	tl_appendf		(Textlist *, char *, ...);
+void	tl_appendf		(Textlist *, char *, ...)
+    __attribute__ ((format (printf, 2, 3)));
 int	tl_print		(Textlist *, FILE *);
 int	tl_print_x		(Textlist *, FILE *, char *);
 void	tl_clear		(Textlist *);
@@ -554,14 +564,16 @@ TmpS   *tmps_realloc		(TmpS *, size_t);
 TmpS   *tmps_find		(char *);
 void    tmps_free		(TmpS *);
 void    tmps_freeall		(void);
-TmpS   *tmps_printf		(const char *, ...);
+TmpS   *tmps_printf		(const char *, ...)
+    __attribute__ ((format (printf, 1, 2)));
 TmpS   *tmps_copy		(char *);
 TmpS   *tmps_stripsize		(TmpS *);
 char   *s_alloc			(size_t);
 char   *s_realloc		(char *, size_t);
 void    s_free			(char *s);
 void    s_freeall		(void);
-char   *s_printf		(const char *, ...);
+char   *s_printf		(const char *, ...)
+    __attribute__ ((format (printf, 1, 2)));
 char   *s_copy			(char *);
 char   *s_stripsize		(char *);
 
@@ -585,4 +597,5 @@ void   *xmalloc			(int);
 void   *xrealloc		(void *, int);
 void	xfree			(void *);
 char   *strsave			(char *);
+char   *strsave2		(char *, char *);
 char   *strsaveline		(char *);
