@@ -2,15 +2,15 @@
 /*****************************************************************************
  * FIDOGATE --- Gateway UNIX Mail/News <-> FIDO NetMail/EchoMail
  *
- * $Id: ftntick.c,v 4.21 1999/06/27 19:18:13 mj Exp $
+ * $Id: ftntick.c,v 4.27 2003/02/16 15:39:02 n0ll Exp $
  *
  * Process incoming TIC files
  *
  *****************************************************************************
- * Copyright (C) 1990-1999
+ * Copyright (C) 1990-2003
  *  _____ _____
- * |     |___  |   Martin Junius             FIDO:      2:2452/110
- * | | | |   | |   Radiumstr. 18             Internet:  mj@fido.de
+ * |     |___  |   Martin Junius             <mj@fidogate.org>
+ * | | | |   | |   Radiumstr. 18
  * |_|_|_|@home|   D-51069 Koeln, Germany
  *
  * This file is part of FIDOGATE.
@@ -37,7 +37,7 @@
 
 
 #define PROGRAM		"ftntick"
-#define VERSION		"$Revision: 4.21 $"
+#define VERSION		"$Revision: 4.27 $"
 #define CONFIG		DEFAULT_CONFIG_MAIN
 
 
@@ -166,8 +166,7 @@ int do_tic(int t_flag)
 	    /*
 	     * Error: rename .tic -> .bad
 	     */
-	    strcpy(buf, name);
-	    strcpy(buf+strlen(buf)-3, "bad");
+	    str_change_ext(buf, sizeof(buf), name, "bad");
 	    rename(name, buf);
 	    log("%s: renamed to %s", name, buf);
 	}
@@ -729,7 +728,4 @@ int main(int argc, char **argv)
 
 
     exit(0);
-
-    /**NOT REACHED**/
-    return 1;
 }
