@@ -2,15 +2,15 @@
 /*****************************************************************************
  * FIDOGATE --- Gateway UNIX Mail/News <-> FIDO NetMail/EchoMail
  *
- * $Id: ftnpack.c,v 4.25 1999/07/23 21:30:13 mj Exp $
+ * $Id: ftnpack.c,v 4.31 2003/02/16 15:39:02 n0ll Exp $
  *
  * Pack output packets of ftnroute for Binkley outbound (ArcMail)
  *
  *****************************************************************************
- * Copyright (C) 1990-1999
+ * Copyright (C) 1990-2003
  *  _____ _____
- * |     |___  |   Martin Junius             FIDO:      2:2452/110
- * | | | |   | |   Radiumstr. 18             Internet:  mj@fido.de
+ * |     |___  |   Martin Junius             <mj@fidogate.org>
+ * | | | |   | |   Radiumstr. 18
  * |_|_|_|@home|   D-51069 Koeln, Germany
  *
  * This file is part of FIDOGATE.
@@ -40,7 +40,7 @@
 
 
 #define PROGRAM 	"ftnpack"
-#define VERSION 	"$Revision: 4.25 $"
+#define VERSION 	"$Revision: 4.31 $"
 #define CONFIG		DEFAULT_CONFIG_MAIN
 
 
@@ -162,7 +162,7 @@ void new_arc(int cmd)
     prog = xstrtok(NULL, " \t");
     if(!name || !prog)
     {
-	log("packing: missing argument for arc/prog definition", name);
+	log("packing: missing argument for arc/prog definition");
 	return;
     }
     
@@ -1299,7 +1299,4 @@ int main(int argc, char **argv)
     }
     
     exit(ret);
-
-    /**NOT REACHED**/
-    return 1;
 }
