@@ -2,15 +2,15 @@
 /*****************************************************************************
  * FIDOGATE --- Gateway UNIX Mail/News <-> FIDO NetMail/EchoMail
  *
- * $Id: ftnroute.c,v 4.25 1999/06/01 20:59:09 mj Exp $
+ * $Id: ftnroute.c,v 4.30 2003/02/16 15:39:02 n0ll Exp $
  *
  * Route FTN NetMail/EchoMail
  *
  *****************************************************************************
- * Copyright (C) 1990-1999
+ * Copyright (C) 1990-2003
  *  _____ _____
- * |     |___  |   Martin Junius             FIDO:      2:2452/110
- * | | | |   | |   Radiumstr. 18             Internet:  mj@fido.de
+ * |     |___  |   Martin Junius             <mj@fidogate.org>
+ * | | | |   | |   Radiumstr. 18
  * |_|_|_|@home|   D-51069 Koeln, Germany
  *
  * This file is part of FIDOGATE.
@@ -40,7 +40,7 @@
 
 
 #define PROGRAM 	"ftnroute"
-#define VERSION 	"$Revision: 4.25 $"
+#define VERSION 	"$Revision: 4.30 $"
 #define CONFIG		DEFAULT_CONFIG_MAIN
 
 
@@ -711,7 +711,4 @@ int main(int argc, char **argv)
     outpkt_close();
 
     exit(ret);
-
-    /**NOT REACHED**/
-    return 1;
 }
