@@ -2,15 +2,15 @@
 /*****************************************************************************
  * FIDOGATE --- Gateway UNIX Mail/News <-> FTN NetMail/EchoMail
  *
- * $Id: history.c,v 4.7 1999/01/02 16:35:06 mj Exp $
+ * $Id: history.c,v 4.12 2003/02/16 15:39:02 n0ll Exp $
  *
  * MSGID history functions and dupe checking
  *
  *****************************************************************************
- * Copyright (C) 1990-1999
+ * Copyright (C) 1990-2003
  *  _____ _____
- * |     |___  |   Martin Junius             FIDO:      2:2452/110
- * | | | |   | |   Radiumstr. 18             Internet:  mj@fido.de
+ * |     |___  |   Martin Junius             <mj@fidogate.org>
+ * | | | |   | |   Radiumstr. 18
  * |_|_|_|@home|   D-51069 Koeln, Germany
  *
  * This file is part of FIDOGATE.
@@ -322,9 +322,6 @@ int main(int argc, char *argv[])
     hi_close();
     
     exit(0);
-
-    /**NOT REACHED**/
-    return 1;
 }
 #endif /**TEST**/
 /*****************************************************************************/
