@@ -2,15 +2,15 @@
 /*****************************************************************************
  * FIDOGATE --- Gateway UNIX Mail/News <-> FIDO NetMail/EchoMail
  *
- * $Id: ftnbsy.c,v 4.4 1999/01/02 16:35:07 mj Exp $
+ * $Id: ftnbsy.c,v 4.9 2003/02/16 15:39:03 n0ll Exp $
  *
  * Command line interface to BinkleyTerm bsy files
  *
  *****************************************************************************
- * Copyright (C) 1990-1999
+ * Copyright (C) 1990-2003
  *  _____ _____
- * |     |___  |   Martin Junius             FIDO:      2:2452/110
- * | | | |   | |   Radiumstr. 18             Internet:  mj@fido.de
+ * |     |___  |   Martin Junius             <mj@fidogate.org>
+ * | | | |   | |   Radiumstr. 18
  * |_|_|_|@home|   D-51069 Koeln, Germany
  *
  * This file is part of FIDOGATE.
@@ -36,7 +36,7 @@
 
 
 #define PROGRAM 	"ftnbsy"
-#define VERSION 	"$Revision: 4.4 $"
+#define VERSION 	"$Revision: 4.9 $"
 #define CONFIG		DEFAULT_CONFIG_MAIN
 
 
@@ -206,7 +206,4 @@ int main(int argc, char **argv)
 
     
     exit(ret);
-
-    /**NOT REACHED**/
-    return 1;
 }
