@@ -2,15 +2,15 @@
 /*****************************************************************************
  * FIDOGATE --- Gateway UNIX Mail/News <-> FIDO NetMail/EchoMail
  *
- * $Id: ftnconfig.c,v 4.8 1999/01/02 16:35:07 mj Exp $
+ * $Id: ftnconfig.c,v 4.13 2003/02/16 15:39:03 n0ll Exp $
  *
  * Fetch FIDOGATE config.* parameters
  *
  *****************************************************************************
- * Copyright (C) 1990-1999
+ * Copyright (C) 1990-2003
  *  _____ _____
- * |     |___  |   Martin Junius             FIDO:      2:2452/110
- * | | | |   | |   Radiumstr. 18             Internet:  mj@fido.de
+ * |     |___  |   Martin Junius             <mj@fidogate.org>
+ * | | | |   | |   Radiumstr. 18
  * |_|_|_|@home|   D-51069 Koeln, Germany
  *
  * This file is part of FIDOGATE.
@@ -36,7 +36,7 @@
 
 
 #define PROGRAM 	"ftnconfig"
-#define VERSION 	"$Revision: 4.8 $"
+#define VERSION 	"$Revision: 4.13 $"
 #define CONFIG		DEFAULT_CONFIG_MAIN
 
 
@@ -223,7 +223,4 @@ int main(int argc, char **argv)
     }
     
     exit( do_para(argv[optind]) ? 0 : 1 );
-    
-    /**NOT REACHED**/
-    return 1;
-}
+    }
