@@ -2,15 +2,15 @@
 /*****************************************************************************
  * FIDOGATE --- Gateway UNIX Mail/News <-> FIDO NetMail/EchoMail
  *
- * $Id: pktdebug.c,v 4.8 1999/04/03 12:13:25 mj Exp $
+ * $Id: pktdebug.c,v 4.13 2003/02/16 15:39:04 n0ll Exp $
  *
  * Debug contents of FTN packet
  *
  *****************************************************************************
- * Copyright (C) 1990-1999
+ * Copyright (C) 1990-2003
  *  _____ _____
- * |     |___  |   Martin Junius             FIDO:      2:2452/110
- * | | | |   | |   Radiumstr. 18             Internet:  mj@fido.de
+ * |     |___  |   Martin Junius             <mj@fidogate.org>
+ * | | | |   | |   Radiumstr. 18
  * |_|_|_|@home|   D-51069 Koeln, Germany
  *
  * This file is part of FIDOGATE.
@@ -37,7 +37,7 @@
 
 
 #define PROGRAM		"pktdebug"
-#define VERSION		"$Revision: 4.8 $"
+#define VERSION		"$Revision: 4.13 $"
 
 
 
@@ -248,8 +248,5 @@ int main(int argc, char **argv)
     }
     
     exit(0);
-
-    /**NOT REACHED**/
-    return 1;
 }
 
