@@ -1,16 +1,17 @@
+	
 /*:ts=8*/
 /*****************************************************************************
  * FIDOGATE --- Gateway UNIX Mail/News <-> FIDO NetMail/EchoMail
  *
- * $Id: sumcrc.c,v 4.3 1999/01/02 16:35:07 mj Exp $
+ * $Id: sumcrc.c,v 4.9 2003/02/16 15:39:05 n0ll Exp $
  *
  * sumcrc32 --- CRC32 checksum computation
  *
  *****************************************************************************
- * Copyright (C) 1990-1999
+ * Copyright (C) 1990-2003
  *  _____ _____
- * |     |___  |   Martin Junius             FIDO:      2:2452/110
- * | | | |   | |   Radiumstr. 18             Internet:  mj@fido.de
+ * |     |___  |   Martin Junius             <mj@fidogate.org>
+ * | | | |   | |   Radiumstr. 18
  * |_|_|_|@home|   D-51069 Koeln, Germany
  *
  * This file is part of FIDOGATE.
@@ -36,7 +37,7 @@
 
 
 #define PROGRAM		"sumcrc32"
-#define VERSION		"$Revision: 4.3 $"
+#define VERSION		"$Revision: 4.9 $"
 
 
 int s1_flag = FALSE;		/* -1 */
@@ -208,7 +209,4 @@ int main(int argc, char **argv)
 	    ret = 1;
     
     exit(ret);
-
-    /**NOT REACHED**/
-    return 1;
 }
