@@ -2,13 +2,13 @@
 /*****************************************************************************
  * FIDOGATE --- Gateway software UNIX Mail/News <-> FIDO NetMail/EchoMail
  *
- * $Id: version.h,v 4.36 1999/06/27 19:18:08 mj Exp $
+ * $Id: version.h,v 4.44 2002/12/16 20:23:37 n0ll Exp $
  *
  * Global version number, patch level
  *****************************************************************************/
 
 #define VERSION_MAJOR	4
-#define VERSION_MINOR	3
-#define PATCHLEVEL	5
+#define VERSION_MINOR	4
+#define PATCHLEVEL	7
 
-#define STATE		"development"
+#define STATE		"stable"
